==> moodle_1.3.1.orig.tar.gz: moodle/lang/es/resource.php <==
<?PHP // $Id: resource.php,v 1.17 2004/05/27 00:22:58 barias Exp $ 
      // resource.php - created with Moodle 1.3 (2004052500)


$string['addresource'] = 'Agregar recurso';
$string['chooseafile'] = 'Elija o suba un archivo';
$string['configdefaulturl'] = 'Este valor se usa como pre-relleno cuando se crea un nuevo recurso basado en URL.';
$string['configfilterexternalpages'] = 'Activar esta variable ocasionar que todos los recursos externos (pginas web, archivos HTML cargados) se procesen segn los filtros definidos en el sitio (como el glosario, los enlaces automticos, etc.). Esto puede hacer que el rendimiento del sistema disminuya considerablemente --selo con cuidado, slo si es necesario.';
$string['configframesize'] = 'Cuando se muestra una pgina web o un archivo cargado dentro de un marco (frame), este valor es el tamao en pxeles del marco superior (top) que contiene el navegador.';
$string['configpopup'] = 'Cuando se agrega un recurso que puede mostrarse en un ventana emergente (\"popup\"), esta opcin se debe activar por defecto?';
$string['configpopupdirectories'] = 'Las ventanas \"popup\", deben por defecto mostrar los enlaces del directorio?';
$string['configpopupheight'] = 'Qu altura deben tener por defecto las ventanas \"popup\"?';
$string['configpopuplocation'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de ubicacin?';
$string['configpopupmenubar'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de men?';
$string['configpopupresizable'] = 'Las ventanas \"popup\", deben por defecto ser redimensionables?';
$string['configpopupscrollbars'] = 'Las ventanas \"popup\", deben por defecto mostrar las barras de desplazamiento?';
$string['configpopupstatus'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de estado?';
$string['configpopuptoolbar'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de herramientas?';
$string['configpopupwidth'] = 'Qu ancho deben tener por defecto las ventanas \"popup\"?';
$string['configwebsearch'] = 'Cuando agregue una URL como pgina web o como enlace, esta ubicacin se ofrece como un sitio para que el usuario busque la URL que desea.';
$string['directlink'] = 'Enlace directo a este archivo';
$string['directoryinfo'] = 'Se mostrarn todos los archivos en el directorio elegido.';
$string['editingaresource'] = 'Editar recurso';
$string['example'] = 'Ejemplo';
$string['examplereference'] = 'Tobin, K. & Tippins, D (1993) Constructivism as a Referent for Teaching and Learning. En: K. Tobin (Ed.). The Practice of Constructivism in Science Education, pp 3-21, Lawrence-Erlbaum, Hillsdale, NJ.';
$string['exampleurl'] = 'http://www.ejemplo.com/directorio/archivo.html';
$string['fetchclienterror'] = 'Ha ocurrido un problema al tratar de abrir la pgina web (posiblemente la direccin est equivocada).';
$string['fetcherror'] = 'Ha ocurrido un problema al tratar de abrir la pgina web.';
$string['fetchservererror'] = 'Ha ocurrido un problema con el servidor remoto al tratar de abrir la pgina web (posiblemente un error del programa).';
$string['filename'] = 'Nombre del archivo';
$string['filtername'] = 'Auto-enlace de recursos';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento HTML';
$string['maindirectory'] = 'Directorio principal de archivos';
$string['modulename'] = 'Recurso';
$string['modulenameplural'] = 'Recursos';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar los enlaces del directorio';
$string['newfullscreen'] = 'Llenar la pantalla';
$string['newheight'] = 'Altura de la ventana (en pxeles)';
$string['newlocation'] = 'Mostrar la barra de ubicacin';
$string['newmenubar'] = 'Mostrar la barra de men';
$string['newresizable'] = 'Permitir cambiar el tamao de la ventana';
$string['newscrollbars'] = 'Permitir desplazamiento en la ventana';
$string['newstatus'] = 'Mostrar la barra de estado';
$string['newtoolbar'] = 'Mostrar la barra de herramientas';
$string['newwidth'] = 'Ancho de la  ventana (en pxeles)';
$string['newwindow'] = 'Nueva ventana';
$string['newwindowopen'] = 'Mostrar el recurso en una nueva ventana emergente (\"popup\")';
$string['note'] = 'Nota';
$string['notefile'] = 'Para subir ms de un archivo (y se puedan ver en la lista) utilice el 
<A HREF=$a >Administrador de archivos</A>.';
$string['notypechosen'] = 'Necesita elegir un texto. Regrese e intntelo de nuevo.';
$string['popupresource'] = 'Este recurso debe aparecer en una ventana ';
$string['popupresourcelink'] = 'Si no, haga clic aqu: $a';
$string['resourcetype'] = 'Tipo de recurso';
$string['resourcetype1'] = 'Referencia';
$string['resourcetype2'] = 'Pgina web (se ver dentro)';
$string['resourcetype3'] = 'Archivo cargado';
$string['resourcetype4'] = 'Texto plano';
$string['resourcetype5'] = 'Pgina web (se ver fuera)';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto Wiki';
$string['resourcetype9'] = 'Directorio';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/es/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 unstable development (2004083000)


$string['addresource'] = 'Agregar recurso';
$string['chooseafile'] = 'Elija o suba un archivo';
$string['chooseparameter'] = 'Elegir parmetro';
$string['configdefaulturl'] = 'Este valor se usa como pre-relleno cuando se crea un nuevo recurso basado en URL.';
$string['configfilterexternalpages'] = 'Activar esta variable ocasionar que todos los recursos externos (pginas web, archivos HTML cargados) se procesen segn los filtros definidos en el sitio (como el glosario, los enlaces automticos, etc.). Esto puede hacer que el rendimiento del sistema disminuya considerablemente --selo con cuidado, slo si es necesario.';
$string['configframesize'] = 'Cuando se muestra una pgina web o un archivo cargado dentro de un marco (frame), este valor es el tamao en pxeles del marco superior (top) que contiene el navegador.';
$string['configparametersettings'] = 'Configura el valor por defecto del panel de ajustes de parmetros en el formulario cuando se agregan nuevos recursos. Tras esta primera vez, se convierte en una preferencia del usuario individual.';
$string['configpopup'] = 'Cuando se agrega un recurso que puede mostrarse en un ventana emergente (\"popup\"), esta opcin se debe activar por defecto?';
$string['configpopupdirectories'] = 'Las ventanas \"popup\", deben por defecto mostrar los enlaces del directorio?';
$string['configpopupheight'] = 'Qu altura deben tener por defecto las ventanas \"popup\"?';
$string['configpopuplocation'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de ubicacin?';
$string['configpopupmenubar'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de men?';
$string['configpopupresizable'] = 'Las ventanas \"popup\", deben por defecto ser redimensionables?';
$string['configpopupscrollbars'] = 'Las ventanas \"popup\", deben por defecto mostrar las barras de desplazamiento?';
$string['configpopupstatus'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de estado?';
$string['configpopuptoolbar'] = 'Las ventanas \"popup\", deben por defecto mostrar la barra de herramientas?';
$string['configpopupwidth'] = 'Qu ancho deben tener por defecto las ventanas \"popup\"?';
$string['configsecretphrase'] = 'Esta frase secreta se usa para generar el valor de cdigo encriptado que se enviar a algunos recursos como parmetro. El cdigo encriptado es producido por un valor md5 de la direccin IP current_users concatenado con su frase secreta. Ej., code = md5(IP.frasesecreta). Esto permite al recurso destinatario verificar la conexin para mayor seguridad.';
$string['configwebsearch'] = 'Cuando agregue una URL como pgina web o como enlace, esta ubicacin se ofrece como un sitio para que el usuario busque la URL que desea.';
$string['configwindowsettings'] = 'Fija el valor por defecto del panel de ajustes de ventana en el formulario cuando se agregan algunos recursos nuevos. Tras esta primera vez, se convierte en una preferencia del usuario individual.';
$string['directlink'] = 'Enlace directo a este archivo';
$string['directoryinfo'] = 'Se mostrarn todos los archivos en el directorio elegido.';
$string['display'] = 'Ventana';
$string['editingaresource'] = 'Editar recurso';
$string['encryptedcode'] = 'Cdigo encriptado';
$string['example'] = 'Ejemplo';
$string['exampleurl'] = 'http://www.ejemplo.com/directorio/archivo.html';
$string['fetchclienterror'] = 'Ha ocurrido un problema al tratar de abrir la pgina web (posiblemente la direccin est equivocada).';
$string['fetcherror'] = 'Ha ocurrido un problema al tratar de abrir la pgina web.';
$string['fetchservererror'] = 'Ha ocurrido un problema con el servidor remoto al tratar de abrir la pgina web (posiblemente un error del programa).';
$string['filename'] = 'Nombre del archivo';
$string['filtername'] = 'Auto-enlace de recursos';
$string['frameifpossible'] = 'Colocar el recurso en un marco para mantener visible la navegacin por el sitio';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento HTML';
$string['maindirectory'] = 'Directorio principal de archivos';
$string['modulename'] = 'Recurso';
$string['modulenameplural'] = 'Recursos';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar los enlaces del directorio';
$string['newfullscreen'] = 'Llenar la pantalla';
$string['newheight'] = 'Altura de la ventana (en pxeles)';
$string['newlocation'] = 'Mostrar la barra de ubicacin';
$string['newmenubar'] = 'Mostrar la barra de men';
$string['newresizable'] = 'Permitir cambiar el tamao de la ventana';
$string['newscrollbars'] = 'Permitir desplazamiento en la ventana';
$string['newstatus'] = 'Mostrar la barra de estado';
$string['newtoolbar'] = 'Mostrar la barra de herramientas';
$string['newwidth'] = 'Ancho de la  ventana (en pxeles)';
$string['newwindow'] = 'Nueva ventana';
$string['newwindowopen'] = 'Mostrar el recurso en una nueva ventana emergente (\"popup\")';
$string['note'] = 'Nota';
$string['notefile'] = 'Para subir ms de un archivo (y se puedan ver en la lista) utilice el 
<A HREF=$a >Administrador de archivos</A>.';
$string['notypechosen'] = 'Necesita elegir un texto. Regrese e intntelo de nuevo.';
$string['pagedisplay'] = 'Mostrar este recurso dentro de la ventana actual';
$string['pagewindow'] = 'La misma ventana';
$string['parameter'] = 'Parmetro';
$string['parameters'] = 'Parmetros';
$string['popupresource'] = 'Este recurso debe aparecer en una ventana ';
$string['popupresourcelink'] = 'Si no, haga clic aqu: $a';
$string['resourcetype'] = 'Tipo de recurso';
$string['resourcetype1'] = 'Referencia';
$string['resourcetype2'] = 'Pgina web';
$string['resourcetype3'] = 'Archivo subido';
$string['resourcetype4'] = 'Texto plano';
$string['resourcetype5'] = 'Enlace web';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto wiki';
$string['resourcetype9'] = 'Directorio';
$string['resourcetypedirectory'] = 'Mostrar un directorio';
$string['resourcetypefile'] = 'Enlazar un archivo o una web';
$string['resourcetypehtml'] = 'Editar una pgina web';
$string['resourcetypelabel'] = 'Aadir una etiqueta';
$string['resourcetypetext'] = 'Editar una pgina de texto';
$string['searchweb'] = 'Buscar una pgina web';
$string['variablename'] = 'Nombre de la variable';

?>
